@@ -8,9 +8,9 @@
 #include <QDebug>
 #include <QGuiApplication>
 #include <QSharedPointer>
-#include <QtWaylandClient/QWaylandClientExtensionTemplate>
-#include <QtWaylandClient/QtWaylandClientVersion>
-#include <qpa/qplatformnativeinterface.h>
+#include <QWaylandClientExtensionTemplate>
+#include <QWindow>
+#include <qpa/qplatformwindow_p.h>
 
 #include "qwayland-keyboard-shortcuts-inhibit-unstable-v1.h"
 
@@ -52,13 +52,7 @@ public:
     ShortcutsInhibitManager()
         : QWaylandClientExtensionTemplate<ShortcutsInhibitManager>(1)
     {
-#if QTWAYLANDCLIENT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
         initialize();
-#else
-        // QWaylandClientExtensionTemplate invokes this with a QueuedConnection but we want shortcuts
-        // to be inhibited immediately.
-        QMetaObject::invokeMethod(this, "addRegistryListener");
-#endif
     }
     ~ShortcutsInhibitManager() override
     {
@@ -72,12 +66,15 @@ public:
         if (m_inhibitions.contains(window)) {
             return;
         }
-        QPlatformNativeInterface *nativeInterface = qGuiApp->platformNativeInterface();
-        if (!nativeInterface) {
+        auto waylandApp = qGuiApp->nativeInterface<QNativeInterface::QWaylandApplication>();
+        auto waylandWindow = window->nativeInterface<QNativeInterface::Private::QWaylandWindow>();
+        if (!waylandApp || !waylandWindow) {
             return;
         }
-        auto seat = static_cast<wl_seat *>(nativeInterface->nativeResourceForIntegration("wl_seat"));
-        auto surface = static_cast<wl_surface *>(nativeInterface->nativeResourceForWindow("surface", window));
+
+        auto seat = waylandApp->lastInputSeat();
+        auto surface = waylandWindow->surface();
+
         if (!seat || !surface) {
             return;
         }
@@ -99,11 +96,11 @@ public:
 
 static std::shared_ptr<ShortcutsInhibitManager> theManager()
 {
-    static std::weak_ptr<ShortcutsInhibitManager> manager;
-    std::shared_ptr<ShortcutsInhibitManager> ret;
+    static std::weak_ptr<ShortcutsInhibitManager> managerInstance;
+    std::shared_ptr<ShortcutsInhibitManager> ret = managerInstance.lock();
     if (!ret) {
         ret = std::make_shared<ShortcutsInhibitManager>();
-        manager = ret;
+        managerInstance = ret;
     }
     return ret;
 }
